@@ -52,3 +52,19 @@ class FrameException(Exception):
     """
 
     pass
+
+
+class ServiceProviderException(Exception):
+    """
+    Service provider is down
+    """
+
+    pass
+
+
+class NoCaptchaException(Exception):
+    """
+    If there is no captcha on the page
+    """
+
+    pass
